import os
from cloudmesh.common.Shell import directory_exists


class Base:

    """
    The Base path for te cloudmesh.yaml file can be set automatically with this class
    The following test are done in that order

    base = Base()

    if CLOUDMESH is set as environment variable it uses that base

    if Base(path=..) is used that path is used
    if a .cloudmesh dir exists in the current directory that dir is used
    otherwise ~/.cloudmesh is used

    """
    def __init__(self, path=None, create=True):

        if path is not None:
            self.path = path

        elif "CLOUDMESH" in os.environ:
            print ("A")
            self.path = os.environ.get("CLOUDMESH")

        elif directory_exists(".cloudmesh"):
            print ("B")
            self.path = ".cloudmesh"

        elif path is None:
            print("C")
            self.path = "~/.cloudmesh"

        # Expand the tilde (~) to the user's home directory path
        self.path = os.path.expanduser(self.path)

        self.config = os.path.join(self.path, "cloudmesh.yaml")
        if create:
            self.create()

    def create(self):
        os.makedirs(self.path, exist_ok=True)
